diff ReAction.lua @ 101:3699d7dad312

added stateful anchoring
author Flick <flickerstreak@gmail.com>
date Sat, 25 Oct 2008 18:49:18 +0000
parents 168cae4aa8bd
children 410d036c43b2
line wrap: on
line diff
--- a/ReAction.lua	Fri Oct 24 23:37:24 2008 +0000
+++ b/ReAction.lua	Sat Oct 25 18:49:18 2008 +0000
@@ -152,9 +152,10 @@
           self:CreateBar(name, config)
         end
       end
       -- re-anchor in case anchor order does not match init order
       for name, bar in pairs(bars) do
         bar:ApplyAnchor()
+        callbacks:Fire("OnRefreshBar", bar, name)
       end
       inited = true
     end
@@ -152,9 +152,10 @@
         end
       end
-      -- re-anchor in case anchor order does not match init order
+      -- re-anchor and refresh in case anchor order does not match init order
       for name, bar in pairs(bars) do
         bar:ApplyAnchor()